package de.bsvrz.sys.funclib.bitctrl.modell.impl;

import de.bsvrz.sys.funclib.bitctrl.modell.Aspekt;
import de.bsvrz.sys.funclib.bitctrl.modell.Datensatz;
import de.bsvrz.sys.funclib.bitctrl.modell.OnlineDatum;
import de.bsvrz.sys.funclib.bitctrl.modell.att.Zeitstempel;

/**
 * Implementiert die Gemeinsamkeiten der Schnittstelle.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public abstract class AbstractOnlineDatum extends AbstractDatum
		implements OnlineDatum {

	private Zeitstempel zeitstempel;
	private Status status = Status.UNDEFINIERT;

	/**
	 * Initialisiert das Onlinedatum.
	 *
	 * @param datensatz
	 *            der Datensatz zu dem das Datum gehört.
	 * @param aspekt
	 *            der Aspekt für das Datum.
	 */
	public AbstractOnlineDatum(final Datensatz datensatz, final Aspekt aspekt) {
		super(datensatz, aspekt);
	}

	@Override
	public Zeitstempel dGetZeitstempel() {
		return zeitstempel;
	}

	@Override
	public void dSetZeitstempel(final Zeitstempel z) {
		zeitstempel = z;
	}

	@Override
	public final boolean dContainsDaten() {
		return dGetDatenStatus() == OnlineDatum.Status.DATEN;
	}

	@Override
	public Status dGetDatenStatus() {
		return status;
	}

	/**
	 * Setzt den aktuellen Status des Datensatzes.
	 *
	 * @param datenStatus
	 *            der neue Status
	 */
	public void dSetDatenStatus(final Status datenStatus) {
		status = datenStatus;
	}

	@Override
	public abstract OnlineDatum clone();

}
